@@ -13,7 +13,8 @@ __docformat__ = 'restructuredtext en'
 from functools import total_ordering
 
 from sknano.core.math import Vector
-from ._extended_atoms import XAtoms
+
+import sknano.core.atoms
 
 __all__ = ['Bond']
 
@@ -28,7 +29,7 @@ class Bond(object):
 
     """
     def __init__(self, atom1, atom2):
-        self._atoms = XAtoms(atoms=[atom1, atom2])
+        self._atoms = sknano.core.atoms.StructureAtoms(atoms=[atom1, atom2])
         self._vector = Vector(atom2.r - atom1.r, p0=atom1.r.p)
 
     def __str__(self):
