@@ -55,18 +55,20 @@ class XAtom(Atom):
     _atomattrs = Atom._atomattrs + \
         ['atomID', 'moleculeID', 'atomtype', 'q', 'dr',
          'r', 'x', 'y', 'z', 'v', 'vx', 'vy', 'vz',
-         'f', 'fx', 'fy', 'fz', 'n', 'nx', 'ny', 'nz']
+         'f', 'fx', 'fy', 'fz', 'n', 'nx', 'ny', 'nz',
+         'pe', 'ke', 'etotal']
 
     __hash__ = Atom.__hash__
 
     def __init__(self, element=None, atomID=0, moleculeID=0, atomtype=1,
-                 q=0., m=None, mass=None, x=None, y=None, z=None,
+                 q=0., mass=None, x=None, y=None, z=None,
                  vx=None, vy=None, vz=None, fx=None, fy=None, fz=None,
-                 nx=None, ny=None, nz=None, **kwargs):
-        if m is None and mass is not None:
-            m = mass
+                 nx=None, ny=None, nz=None, pe=None, ke=None, etotal=None,
+                 **kwargs):
+        if mass is None and 'm' in kwargs:
+            mass = kwargs['m']
 
-        super(XAtom, self).__init__(element=element, m=m)
+        super(XAtom, self).__init__(element=element, mass=mass)
 
         self.r = Vector([x, y, z])
         #self._p0 = Point([x, y, z])
@@ -81,15 +83,30 @@ class XAtom(Atom):
         self._atomtype = int(atomtype)
         self._q = q
 
+        self.pe = pe
+        self.ke = ke
+        self.etotal = etotal
+
+    def __str__(self):
+        """Return nice string representation of `XAtom`."""
+        strrep = "Atom(element={element!r}, atomID={atomID!r}, " + \
+            "moleculeID={moleculeID!r}, atomtype={atomtype!r})"
+        parameters = dict(element=self.element, atomID=self.atomID,
+                          moleculeID=self.moleculeID, atomtype=self.atomtype)
+
+        return strrep.format(**parameters)
+
     def __repr__(self):
-        """Return string representation of `XAtom`."""
+        """Return canonical string representation of `XAtom`."""
         reprstr = "Atom(element={element!r}, atomID={atomID!r}, " + \
             "moleculeID={moleculeID!r}, atomtype={atomtype!r}, " + \
-            "q={q!r}, mass={mass!r}, x={x:.6f}, y={y:.6f}, z={z:.6f})"
+            "q={q!r}, mass={mass!r}, x={x:.6f}, y={y:.6f}, z={z:.6f}, " \
+            "pe={pe!r}, ke={ke!r}, etotal={etotal!r})"
         parameters = dict(element=self.element, atomID=self.atomID,
                           moleculeID=self.moleculeID, atomtype=self.atomtype,
                           q=self.q, mass=self.mass,
-                          x=self.x, y=self.y, z=self.z)
+                          x=self.x, y=self.y, z=self.z,
+                          pe=self.pe, ke=self.ke, etotal=self.etotal)
 
         return reprstr.format(**parameters)
 
@@ -181,14 +198,6 @@ class XAtom(Atom):
             raise TypeError('Expected a number')
         self._atomtype = int(value)
 
-    @property
-    def mass(self):
-        return self.m
-
-    @mass.setter
-    def mass(self, value):
-        self.m = value
-
     @property
     def x(self):
         """:math:`x`-coordinate in units of **Angstroms**.
@@ -628,6 +637,48 @@ class XAtom(Atom):
             raise TypeError('Expected an array_like object')
         self._f = Vector(value)
 
+    @property
+    def pe(self):
+        """`Atom` potential energy."""
+        return self._pe
+
+    @pe.setter
+    def pe(self, value):
+        if not isinstance(value, (float, type(None))):
+            raise TypeError('Expected a number')
+        if value is None:
+            value = 0.0
+        self._pe = value
+
+    @property
+    def ke(self):
+        """`Atom` kinetic energy."""
+        return self._ke
+
+    @ke.setter
+    def ke(self, value):
+        if not isinstance(value, (float, type(None))):
+            raise TypeError('Expected a number')
+        if value is None:
+            value = 0.0
+        self._ke = value
+
+    @property
+    def etotal(self):
+        """`Atom` total energy (:attr:`~XAtoms.pe` + :attr:`~XAtoms.ke`)."""
+        return self._etotal
+
+    @etotal.setter
+    def etotal(self, value):
+        if not isinstance(value, (float, type(None))):
+            raise TypeError('Expected a number')
+        if value is None:
+            try:
+                value = self.pe + self.ke
+            except TypeError:
+                value = 0.0
+        self._etotal = value
+
     def rezero(self, epsilon=1.0e-10):
         """Re-zero position vector components.
 
@@ -688,4 +739,5 @@ class XAtom(Atom):
                     x=self.x, y=self.y, z=self.z,
                     vx=self.vx, vy=self.vy, vz=self.vz,
                     fx=self.fx, fy=self.fy, fz=self.fz,
-                    nx=self.nx, ny=self.ny, nz=self.nz)
+                    nx=self.nx, ny=self.ny, nz=self.nz,
+                    pe=self.pe, ke=self.ke, etotal=self.etotal)
