@@ -20,6 +20,10 @@ def test_attributes():
         assert_equals(xatom.element, element)
         assert_equals(xatom.m, xatom.mass)
 
+    xatom = XAtom()
+    for c in ('x', 'y', 'z'):
+        assert_equals(getattr(xatom, c), 0.0)
+
 
 def test_str():
     atom = XAtom('C')
