@@ -11,7 +11,7 @@ from sknano.testing import GeneratorTestFixtures
 class TestCase(GeneratorTestFixtures):
 
     def test1(self):
-        bundle = MWNTBundleGenerator(max_shells=2, Lz=1.0, fix_Lz=True,
+        bundle = MWNTBundleGenerator(max_shells=2, Lz=1.0,
                                      bundle_geometry='hexagon')
         bundle.save_data()
         self.tmpdata.append(bundle.fname)
@@ -20,7 +20,7 @@ class TestCase(GeneratorTestFixtures):
 
     def test2(self):
         Ch = [(5,5), (10,10), (15, 15), (20, 20)]
-        bundle = MWNTBundleGenerator(Ch=Ch, Lz=0.5, fix_Lz=True,
+        bundle = MWNTBundleGenerator(Ch=Ch, Lz=0.5,
                                      bundle_geometry='hexagon')
         bundle.save_data()
         self.tmpdata.append(bundle.fname)
@@ -29,7 +29,7 @@ class TestCase(GeneratorTestFixtures):
 
     def test3(self):
         Ch = [(3,3), (4, 4), (5,5)]
-        bundle = MWNTBundleGenerator(Ch=Ch, nx=5, ny=2, Lz=0.5, fix_Lz=True)
+        bundle = MWNTBundleGenerator(Ch=Ch, nx=5, ny=2, Lz=0.5)
         bundle.save_data()
         self.tmpdata.append(bundle.fname)
         bundle.save_data(structure_format='data')
