@@ -11,7 +11,7 @@ from sknano.testing import GeneratorTestFixtures
 class TestCase(GeneratorTestFixtures):
 
     def test1(self):
-        mwnt = MWNTGenerator(max_shells=3, Lz=1.0, fix_Lz=True)
+        mwnt = MWNTGenerator(max_shells=3, Lz=1.0)
         print(mwnt)
         print(mwnt.todict())
         mwnt.save_data()
@@ -20,7 +20,7 @@ class TestCase(GeneratorTestFixtures):
         self.tmpdata.append(mwnt.fname)
 
     def test2(self):
-        mwnt = MWNTGenerator(Ch=[(10, 10), (50, 50)], Lz=1.0, fix_Lz=True)
+        mwnt = MWNTGenerator(Ch=[(10, 10), (50, 50)], Lz=1.0)
         print(mwnt)
         print(mwnt.todict())
         assert_equal(mwnt.Nwalls, 2)
@@ -31,7 +31,7 @@ class TestCase(GeneratorTestFixtures):
         self.tmpdata.append(mwnt.fname)
 
     def test3(self):
-        mwnt = MWNTGenerator(Ch=[(5, 5), (10, 10), (20, 20)], nz=5.0)
+        mwnt = MWNTGenerator(Ch=[(5, 5), (10, 10), (20, 20)], Lz=1.0)
         print(mwnt)
         print(mwnt.todict())
         assert_equal(mwnt.Nwalls, 3)
