@@ -190,7 +190,7 @@ def filter_Ch(Ch, even_only=False, odd_only=False, Ch_type=None,
 
 
 def filter_Ch_list(Ch_list, property_filters=None, **kwargs):
-    """Filter list of chiralities by properties.
+    """Filter list of chiralities.
 
     Parameters
     ----------
@@ -202,12 +202,13 @@ def filter_Ch_list(Ch_list, property_filters=None, **kwargs):
 
     Returns
     -------
-    sequence
-        list of chiralities which passed conditions
+    :class:`python:list`
+        filtered `Ch_list`
 
     """
-    from ._swnt import SWNT
+    #Ch_list = np.asarray(Ch_list)
     if property_filters is not None:
+        from ._swnt import SWNT
         filtered_list = Ch_list[:]
         try:
             for filter_index, (prop, cmp_symbol, value) in \
@@ -232,7 +233,7 @@ def filter_Ch_list(Ch_list, property_filters=None, **kwargs):
 
 def generate_Ch_list(ns=None, ni=None, nf=None, dn=None,
                      ms=None, mi=None, mf=None, dm=None,
-                     chiral_type=None, handedness=None,
+                     imax=None, chiral_type=None, handedness=None,
                      echo_zsh_str=False):
     """Generate a list of :math:`(n, m)` chiralities.
 
@@ -250,6 +251,8 @@ def generate_Ch_list(ns=None, ni=None, nf=None, dn=None,
         `step` parameters passed to the numpy function `np.arange`,
         to generate an array of evenly spaced :math:`m` chiral indices.
         `mi` only required if `ms` sequence kwarg is `None`.
+    imax : int, optional
+        maximum chiral index :math:`n = m = i_{max}`.
     chiral_type : {'all', 'achiral', 'chiral', 'armchair', 'zigzag'}, optional
     handedness : {'all', 'left', 'right'}, optional
     echo_zsh_str : bool, optional
@@ -261,6 +264,9 @@ def generate_Ch_list(ns=None, ni=None, nf=None, dn=None,
 
     """
     Ch_list = []
+    if imax is not None:
+        nf = mf = imax
+
     try:
         if (not ns or (isinstance(ns, list) and ns[0] is None)) \
                 and not ni and not nf and \
@@ -300,7 +306,8 @@ def generate_Ch_list(ns=None, ni=None, nf=None, dn=None,
                             ns = [int(float(ni))]
         if (not ms or isinstance(ms, list) and ms[0] is None) and \
                 not mi and not mf:
-            if chiral_type in (list(Ch_types.keys()) + list(Ch_types.values())):
+            if chiral_type in \
+                    (list(Ch_types.keys()) + list(Ch_types.values())):
                 if chiral_type in ('achiral', 'aCh'):
                     for n in ns:
                         Ch_list.append((n, n))
