@@ -28,8 +28,7 @@ def test2():
 
 
 def test3():
-    mwnt = MWNT(Ch=[(5, 5), (10, 10), (15, 15), (20, 20)],
-                Lz=2.5, fix_Lz=True)
+    mwnt = MWNT(Ch=[(5, 5), (10, 10), (15, 15), (20, 20)], Lz=2.5)
     print(mwnt)
     print(mwnt.todict())
     print(mwnt.chiral_types)
@@ -41,7 +40,7 @@ def test3():
 
 def test4():
     mwnt = MWNT(Ch=[(5, 0), (5, 5), (10, 5), (10, 0), (10, 10), (20, 10)],
-                nz=5.0)
+                Lz=1.0)
     print(mwnt)
     print(mwnt.todict())
     print(mwnt.chiral_types)
